import { ProfileInfo } from "../ProfileInfo";
/**
 * This is the structure of the input options to be supplied to ConvertV1Profiles.convert.
 */
export interface IConvertV1ProfOpts {
    deleteV1Profs: boolean;
    profileInfo?: ProfileInfo;
}
/**
 * Message formatting constants. They can be ORed into IConvertMsg.msgFormat.
 * Do not combine REPORT_LINE and ERROR_LINE.
 */
export declare enum ConvertMsgFmt {
    REPORT_LINE = 1,
    ERROR_LINE = 2,
    PARAGRAPH = 4,
    INDENT = 8
}
/**
 * This is the structure of a conversion message.
 */
export declare class ConvertMsg {
    msgFormat: number;
    msgText: string;
    constructor(msgFormat: number, msgText: string);
}
/**
 * This is the structure of the result from ConvertV1Profiles.convert.
 */
export interface IConvertV1ProfResult {
    /**
     * A report of actions and any error messages are contained in msgs.
     * Each entry contains one line of text. No formatting or newlines are embedded.
     * The caller is free to format the result as desired, using the msgType as a guide.
     */
    msgs: ConvertMsg[];
    /**
     * If the old V1 Secure Credential Store plugin is currently installed, its
     * name is returned in this property. The old SCS plugin will not be used,
     * but the customer should probably uninstall it. Our caller can automatically
     * uninstall that SCS plugin, or if our caller is unable to do so, our
     * caller could inform the user that the plugin should be uninstalled.
     *
     * If the V1 SCS plugin is not installed, the property value will be null.
     */
    v1ScsPluginName: string | null;
    /**
     * This property indicates whether secure credentials were migrated during conversion.
     *
     * If the old V1 Secure Credential Store plugin was supplying the credential manager
     * override and the CredentialManager was initialized before calling this function,
     * profile conversion will not be able to migrate credentials from the old SCS plugin
     * to the current embedded Secure Credential Store.
     */
    credsWereMigrated: boolean;
    /**
     * The following properties contain information about the success or failure of
     * the conversion of V1 profiles. By displaying the values in the 'msgs' property,
     * the caller need not use the following properties. However, our caller could
     * decide to take special action or display custom messages, using the following
     * properties.
     */
    cfgFilePathNm: string;
    numProfilesFound: number;
    profilesConverted: {
        [key: string]: string[];
    };
    profilesFailed: {
        name?: string;
        type: string;
        error: Error;
    }[];
}
//# sourceMappingURL=IConvertV1Profiles.d.ts.map